@@ -5,14 +5,18 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION = "0.10";
+    our $VERSION = "0.12";
     our @EXPORT_OK = qw/parse_urlencoded build_urlencoded/;
 
     my $use_pp = $ENV{WWW_FORM_URLENCODED_PP};
 
     if (!$use_pp) {
-        eval { 
+        eval {
             require WWW::Form::UrlEncoded::XS;
+            if ( $WWW::Form::UrlEncoded::XS::VERSION < $VERSION ) {
+                warn "WWW::Form::UrlEncoded::XS $VERSION is require. fallback to PP version";
+                die;
+            }
         };
         $use_pp = !!$@;
     }
@@ -119,7 +123,17 @@ parse C<$str> and return Array that contains key-value pairs.
 
 =item $string = build_urlencoded(@param)
 
-build urlencoded string from C<@params>
+=item $string = build_urlencoded(\@param)
+
+=item $string = build_urlencoded(\%param)
+
+build urlencoded string from B<param>. build_urlencoded accepts arrayref and hashref values.
+
+  build_urlencoded( foo => 1, foo => 2);
+  build_urlencoded( foo => [1,2] );
+  build_urlencoded( [ foo => 1, foo => 2 ] );
+  build_urlencoded( [foo => [1,2]] );
+  build_urlencoded( {foo => [1,2]} );
 
 =back
 
